package main

import (
	"context"
	"flag"
	"fmt"
	"log"
	"net/http"

	"github.com/redis/go-redis/v9"

	"sunshine.industries/some-automoderation/rooms"
	"sunshine.industries/some-automoderation/routes"
	"sunshine.industries/some-automoderation/sessions"
)

var ctx = context.Background()

func main() {
	var port int
	flag.IntVar(&port, "port", 8080, "Port on which the server should start")
	flag.Parse()
	var redisPort int
	flag.IntVar(&redisPort, "redisPort", 7777, "Port on which server should connect to redis db")

	rdb := redis.NewClient(&redis.Options{
		Addr: fmt.Sprintf("localhost:%d", redisPort),
		Password: "",
		DB: 0,
	})

	roomsM := rooms.RedisRM { Rdb: rdb, }
	sessions := sessions.RedisSM{ Rdb: rdb, }

	log.Printf("Server will start on port %d\n", port)
	routes.RegisterRoutes(sessions, roomsM)

	log.Fatal(http.ListenAndServe(fmt.Sprintf(":%d", port), nil))
}
